@@ -1,13 +1,13 @@
 /** ===========================================================
  * @file
  *
- * This file is a part of digiKam project
- * <a href="http://www.digikam.org">http://www.digikam.org</a>
+ * This file is a part of KDE project
+ *
  *
  * @date   2004-02-01
  * @brief  main kipi host application interface
  *
- * @author Copyright (C) 2004-2016 by Gilles Caulier
+ * @author Copyright (C) 2004-2018 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  * @author Copyright (C) 2006-2012 by Marcel Wiesweg
  *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
@@ -66,8 +66,7 @@ class UploadWidget;
 /*!
   @enum KIPI::Features
   Not all host applications support the full subset of features that KIPI
-  allows access to. As an example <a href="http://www.digikam.org">digiKam</a> support comments
-  for albums. Thus before a plugin expect a decant value for the comment,
+  allows access to. Thus before a plugin expect a decant value for the comment,
   it should check whether KIPI::CollectionsHaveComments are set. It does so
   using KIPI::Interface::hasFeature().
 */
@@ -335,7 +334,7 @@ public:
     /**
      * Tells to host application to render a preview image for one item.
      * A resizement to to a specific size will be generated if preview is largest than.
-     * Use a positive resizedTo value in this case, else -1. Aspect ratio is preserved while rendering. 
+     * Use a positive resizedTo value in this case, else -1. Aspect ratio is preserved while rendering.
      * This asynchronous method must be re-implemented in host application.
      * Use gotPreview() signal to take preview.
      */
@@ -354,7 +353,7 @@ public:
     virtual void thumbnails(const QList<QUrl>& list, int size);
 
     /**
-      Ask to Kipi host application to prepare progress manager for a new entry. This method must return from host 
+      Ask to Kipi host application to prepare progress manager for a new entry. This method must return from host
       a string identification about progress item created. This id will be used later to change in host progress item
       value and text. Title is text used to name progress item in host application.
       Set canBeCanceled to true if you want that progress item provide a cancel button to close process from kipi host.
@@ -424,7 +423,7 @@ public:
      * The implementation from KIPI host application must be thread-safe.
      *
      */
-    virtual FileReadWriteLock* createReadWriteLock(const QUrl& url) const = 0;
+    virtual FileReadWriteLock* createReadWriteLock(const QUrl& url) const;
 
     /**
      * Supported if HostSupportsMetadataProcessing.
@@ -432,7 +431,7 @@ public:
      * The implementation from KIPI host application must be thread-safe.
      *
      */
-    virtual MetadataProcessor* createMetadataProcessor() const = 0;
+    virtual MetadataProcessor* createMetadataProcessor() const;
 
     /**
      * Supported if HostSupportsEditHints
@@ -466,12 +465,12 @@ Q_SIGNALS:
     void selectionChanged(bool hasSelection);
 
     /**
-     * Emit when current album selection as changed from host application user interface. 
+     * Emit when current album selection as changed from host application user interface.
      * Boolean argument is true if album are select or not in collection.
      */
     void currentAlbumChanged(bool hasSelection);
 
-    /** Emit when host application has rendered item thumbnail. See asynchronous thumbnail() and thumbnails() 
+    /** Emit when host application has rendered item thumbnail. See asynchronous thumbnail() and thumbnails()
      *  methods for details.
      */
     void gotThumbnail(const QUrl&, const QPixmap&);
