@@ -1,15 +1,15 @@
 /** ===========================================================
  * @file
  *
- * This file is a part of kipi-plugins project
- * <a href="http://www.digikam.org">http://www.digikam.org</a>
+ * This file is a part of KDE project
+ *
  *
  * @date   2009-11-21
  * @brief  kipi host test application
  *
  * @author Copyright (C) 2009-2010 by Michael G. Hansen
  *         <a href="mailto:mike at mghansen dot de">mike at mghansen dot de</a>
- * @author Copyright (C) 2011-2017 by Gilles Caulier
+ * @author Copyright (C) 2011-2018 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  *
  * This program is free software; you can redistribute it
@@ -43,10 +43,10 @@ public:
     KipiImageInfoShared(Interface* const interface, const QUrl& url);
     ~KipiImageInfoShared();
 
-    QMap<QString, QVariant> attributes();
-    void                    addAttributes(const QMap<QString, QVariant>& attributes);
-    void                    delAttributes(const QStringList& attributes);
-    void                    clearAttributes();
+    QMap<QString, QVariant> attributes() Q_DECL_OVERRIDE;
+    void                    addAttributes(const QMap<QString, QVariant>& attributes) Q_DECL_OVERRIDE;
+    void                    delAttributes(const QStringList& attributes) Q_DECL_OVERRIDE;
+    void                    clearAttributes() Q_DECL_OVERRIDE;
 
 private:
 
